import { ApiAction, ApiActionPage } from '../../model/baseModel';
import {
  FluentJobParam,
  Tsk_JobPageListGetResultModel,
  Tsk_JobPageParams,
  Tsk_TrigListItem,
  TskParameter,
} from '../model/tskModel';
import { genAction, Api, genActionPage, generateAction } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { useGlobSetting } from '/@/hooks/setting';

const globSetting = useGlobSetting();
/*
 * 获取角色分页列表
 */
export const getTsk_JobListByPage = async (params: Tsk_JobPageParams) => {
  const id = '';
  if (params?.Status != undefined && params?.Status != '') {
    let sqlcmdt = '';
    sqlcmdt += " STATUS = '" + params?.Status + "'";
    const _data = await defHttp.post<ApiAction<Tsk_TrigListItem[]>>(
      { url: Api.EntityList, params: genAction('TSK_TRIG', sqlcmdt, undefined, true) },
      {
        isTransformResponse: false,
        apiUrl: globSetting.taskApiUrl,
      },
    );
    let sqlcmd = '';
    _data.Data.forEach((item, index) => {
      if (index == 0) {
        sqlcmd += "and ID='" + item.JobId + "'";
      } else {
        sqlcmd += "Or ID='" + item.JobId + "'";
      }
    });
    const rParams = genActionPage('TSK_JOB', sqlcmd, params.page, params.pageSize);
    return getTsk_JobListByPageAsync(rParams);
  } else {
    let sqlcmd = '';
    if (id != undefined && id != '') {
      sqlcmd += " And ID = '" + id + "'";
    }
    if (params?.JobName != undefined && params?.JobName != '') {
      sqlcmd += " And JobName like '%" + params?.JobName + "%'";
    }
    if (params?.CREATE_TIME != undefined && params?.CREATE_TIME != '') {
      sqlcmd += "And CREATE_TIME > '" + params?.CREATE_TIME[0] + "'";
    }
    if (params?.CREATE_TIME != undefined && params?.CREATE_TIME != '') {
      sqlcmd += "And CREATE_TIME < '" + params?.CREATE_TIME[1] + "'";
    }
    const rParams = genActionPage('TSK_JOB', sqlcmd, params.page, params.pageSize);
    return getTsk_JobListByPageAsync(rParams);
  }
};
async function getTsk_JobListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
  const model: Tsk_JobPageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
  };
  // data.Data.data.forEach(function(item) {

  //   defHttp.post(
  //     { url: Api.AddJob, params: genActionjob(item.JobType, item.AssemblyName,item.JobName,item.Triggers[0].Args) },
  //     {
  //       errorMessageMode: 'none',
  //       isTransformResponse: false,
  //     },
  //   );
  // });
  return model;
}

/**
 * 保存任务
 */
export const SaveTskJob = async (params: TskParameter) => {
  const usParams = genAction('TSK_JOB', params);
  return await defHttp.post(
    { url: Api.SaveTskJob, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};

/**
 * @desc 添加任务
 * @param {FluentJobParam} params - 参数列表
 */
export const AddTskJob = async (params: FluentJobParam) => {
  const usParams = generateAction(params.DataType, params.AssemblyName, params);
  return await defHttp.post(
    { url: Api.AddTskJob, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};

/**
 * @desc 立即运行任务
 */
export const ImmediateRun = async (params: FluentJobParam) => {
  const usParams = generateAction(params.DataType, params.AssemblyName, params.JobName);
  return await defHttp.post(
    { url: Api.ImmediateRun, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};

/**
 * @desc 删除
 * @param {Recordable} params - 记录
 */
export const DeleteTsk_Job = async (params: Recordable) => {
  const usParams = genAction('TSK_JOB', [params]);
  const usParamstrig = genAction('TSK_TRIG', params.Triggers);
  return await defHttp
    .post(
      { url: Api.DeleteList, params: usParams },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
        apiUrl: globSetting.taskApiUrl,
      },
    )
    .then(() => {
      defHttp.post(
        { url: Api.DeleteList, params: usParamstrig },
        {
          errorMessageMode: 'none',
          isTransformResponse: false,
          apiUrl: globSetting.taskApiUrl,
        },
      );
    });
};
/**
 * @desc 开始任务
 */
export const StartTsk_Job = async (params: Recordable) => {
  const usParams = genAction('TSK_JOB', params.JobName);
  return await defHttp.post(
    { url: Api.StartJob, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};

/**
 * @desc 停止任务
 */
export const StopTsk_Job = async (params: Recordable) => {
  const usParams = genAction('TSK_JOB', params.JobName);
  return await defHttp.post(
    { url: Api.RemoveTskJob, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};
//下拉列表
export const optionsListApi = async () => {
  const usParams = genAction('TSK_TRIG+Statuss', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      apiUrl: globSetting.taskApiUrl,
    },
  );
};
